@@ -45,22 +45,6 @@ class SelectOverlay(OptionList):
 
     BINDINGS = [("escape", "dismiss", "Dismiss menu")]
 
-    DEFAULT_CSS = """
-    SelectOverlay {
-        border: tall $background;
-        background: $panel;
-        color: $text;
-        width: 100%;
-        padding: 0 1;
-    }
-    SelectOverlay:focus {
-        border: tall $background;
-    }
-    SelectOverlay > .option-list--option {
-        padding: 0 1;
-    }
-    """
-
     @dataclass
     class Dismiss(Message):
         """Inform ancestor the overlay should be dismissed."""
@@ -110,22 +94,28 @@ class SelectCurrent(Horizontal):
 
     DEFAULT_CSS = """
     SelectCurrent {
-        border: tall transparent;
-        background: $boost;
-        color: $text;
-        width: 100%;
+        border: tall $border-blurred;
+        color: $foreground;
+        background: $surface;
+        width: 1fr;
         height: auto;
         padding: 0 2;
 
+        &:ansi {
+            border: tall ansi_blue;
+            color: ansi_default;
+            background: ansi_default;
+        }
+
         Static#label {
             width: 1fr;
             height: auto;
-            color: $text-disabled;
+            color: $foreground 50%;
             background: transparent;
         }
 
         &.-has-value Static#label {
-            color: $text;
+            color: $foreground;
         }
 
         .arrow {
@@ -133,7 +123,7 @@ class SelectCurrent(Horizontal):
             width: 1;
             height: 1;
             padding: 0 0 0 1;
-            color: $text-muted;
+            color: $foreground 50%;
             background: transparent;
         }
     }
@@ -177,7 +167,7 @@ class SelectCurrent(Horizontal):
         """Toggle the class."""
         self.set_class(has_value, "-has-value")
 
-    async def _on_click(self, event: events.Click) -> None:
+    def _on_click(self, event: events.Click) -> None:
         """Inform ancestor we want to toggle."""
         event.stop()
         self.post_message(self.Toggle())
@@ -211,6 +201,16 @@ class Select(Generic[SelectType], Vertical, can_focus=True):
     DEFAULT_CSS = """
     Select {
         height: auto;
+        color: $foreground;
+        
+        .up-arrow {
+            display: none;
+        }
+
+        &:focus > SelectCurrent {
+            border: tall $border;
+            background-tint: $foreground 5%;
+        }
 
         & > SelectOverlay {
             width: 1fr;
@@ -219,31 +219,29 @@ class Select(Generic[SelectType], Vertical, can_focus=True):
             max-height: 12;
             overlay: screen;
             constrain: none inside;
+            color: $foreground;
+            border: tall $border-blurred;
+            background: $surface;
+            &:focus {
+                background-tint: $foreground 5%;
+            }
+            & > .option-list--option {
+                padding: 0 1;
+            }
         }
 
-        &:focus > SelectCurrent {
-            border: tall $accent;
+        &.-expanded {
+            .down-arrow {
+                display: none;
+            }
+            .up-arrow {
+                display: block;
+            }
+            & > SelectOverlay {
+                display: block;
+            }
         }
 
-        .up-arrow {
-            display: none;
-        }
-
-        &.-expanded .down-arrow {
-            display: none;
-        }
-
-        &.-expanded .up-arrow {
-            display: block;
-        }
-
-        &.-expanded > SelectOverlay {
-            display: block;
-        }
-
-        &.-expanded > SelectCurrent {
-            border: tall $accent;
-        }
     }
 
     """
@@ -380,6 +378,18 @@ class Select(Generic[SelectType], Vertical, can_focus=True):
             disabled=disabled,
         )
 
+    @property
+    def selection(self) -> SelectType | None:
+        """The currently selected item.
+
+        Unlike [value][textual.widgets.Select.value], this will not return Blanks.
+        If nothing is selected, this will return `None`.
+
+        """
+        value = self.value
+        assert not isinstance(value, NoSelection)
+        return value
+
     def _setup_variables_for_options(
         self,
         options: Iterable[tuple[RenderableType, SelectType]],
@@ -503,7 +513,7 @@ class Select(Generic[SelectType], Vertical, can_focus=True):
             return
         self.set_class(expanded, "-expanded")
         if expanded:
-            overlay.focus()
+            overlay.focus(scroll_visible=False)
             if self.value is self.BLANK:
                 overlay.select(None)
                 self.query_one(SelectCurrent).has_value = False
